@@ -2,14 +2,18 @@
 
 ;;; Code:
 
+(autoload 'custom-add-loads "cus-load")
+
 (custom-add-loads 'texinfo '("document"))
 (custom-add-loads 'speedbar '("semantic-sb"))
 (custom-add-loads 'document '("document-vars" "document"))
 (custom-add-loads 'semantic-faces '("semantic-mode"))
+(custom-add-loads 'senator '("senator"))
 (custom-add-loads 'lisp '("working"))
-(custom-add-loads 'semantic '("document" "semantic-imenu" "semantic-mode" "semantic"))
+(custom-add-loads 'semantic '("document" "semantic-imenu" "semantic-mode" "semantic" "senator"))
 (custom-add-loads 'working '("working"))
 (custom-add-loads 'imenu '("semantic-imenu"))
+(custom-add-loads 'isearch '("senator-isearch"))
 (custom-add-loads 'c '("semantic-c"))
 
 ;;; custom-load.el ends here
